==> funcnodes_react_flow-1.0.2.tar.gz: funcnodes_react_flow-1.0.2/src/react/packages/funcnodes-react-flow/src/features/nodes/hooks/useBodyDataRendererForIo.ts <==
import { useContext } from "react";
import { RenderOptions } from "@/data-rendering-types";
import { useFuncNodesContext } from "@/providers";
import { pick_best_io_type } from "../components/node-renderer/io/io";
import {
  DataViewRendererToDataPreviewViewRenderer,
  FallbackDataViewRenderer,
  useDataOverlayRendererForIo,
  RenderMappingContext,
} from "@/data-rendering";
import {
  DataOverlayRendererType,
  DataPreviewViewRendererType,
} from "@/data-rendering-types";
import { FuncNodesReactFlow } from "@/funcnodes-context";
import { IOType } from "@/nodes-core";

const useBodyDataRendererForIo = (
  io?: IOType
): [
  DataPreviewViewRendererType | undefined,
  DataOverlayRendererType | undefined
] => {
  const fnrf_zst: FuncNodesReactFlow = useFuncNodesContext();
  const overlayhandle = useDataOverlayRendererForIo(io);
  const { DataPreviewViewRenderer, DataViewRenderer } =
    useContext(RenderMappingContext);

  const render: RenderOptions = fnrf_zst.render_options();

  if (io === undefined) return [undefined, overlayhandle];

  const [typestring] = pick_best_io_type(io, render.typemap || {});

  if (!typestring)
    return [
      DataViewRendererToDataPreviewViewRenderer(FallbackDataViewRenderer),
      overlayhandle,
    ];

  if (DataPreviewViewRenderer[typestring])
    return [DataPreviewViewRenderer[typestring], overlayhandle];

  if (DataViewRenderer[typestring])
    return [
      DataViewRendererToDataPreviewViewRenderer(DataViewRenderer[typestring]),
      overlayhandle,
    ];

  return [
    DataViewRendererToDataPreviewViewRenderer(FallbackDataViewRenderer),
    overlayhandle,
  ];
};

export { useBodyDataRendererForIo };

==> funcnodes_react_flow-2.1.1.tar.gz: funcnodes_react_flow-2.1.1/src/react/packages/funcnodes-react-flow/src/features/nodes/hooks/useBodyDataRendererForIo.ts <==
import { useContext } from "react";
import { RenderOptions } from "@/data-rendering-types";
import { useFuncNodesContext } from "@/providers";
import { pick_best_io_type } from "../pick_best_io_type";
import {
  DataViewRendererToDataPreviewViewRenderer,
  FallbackDataViewRenderer,
  useDataOverlayRendererForIo,
  RenderMappingContext,
} from "@/data-rendering";
import {
  DataOverlayRendererType,
  DataPreviewViewRendererType,
} from "@/data-rendering-types";
import { FuncNodesReactFlow } from "@/funcnodes-context";
import { IOType } from "@/nodes-core";

const useBodyDataRendererForIo = (
  io?: IOType
): [
  DataPreviewViewRendererType | undefined,
  DataOverlayRendererType | undefined
] => {
  const fnrf_zst: FuncNodesReactFlow = useFuncNodesContext();
  const overlayhandle = useDataOverlayRendererForIo(io);
  const { DataPreviewViewRenderer, DataViewRenderer } =
    useContext(RenderMappingContext);

  const render: RenderOptions = fnrf_zst.render_options();

  if (io === undefined) return [undefined, overlayhandle];

  const [typestring] = pick_best_io_type(io, render.typemap || {});

  if (!typestring)
    return [
      DataViewRendererToDataPreviewViewRenderer(FallbackDataViewRenderer),
      overlayhandle,
    ];

  if (DataPreviewViewRenderer[typestring])
    return [DataPreviewViewRenderer[typestring], overlayhandle];

  if (DataViewRenderer[typestring])
    return [
      DataViewRendererToDataPreviewViewRenderer(DataViewRenderer[typestring]),
      overlayhandle,
    ];

  return [
    DataViewRendererToDataPreviewViewRenderer(FallbackDataViewRenderer),
    overlayhandle,
  ];
};

export { useBodyDataRendererForIo };
